#[unsafe(no_mangle)]pub unsafe extern "C" fn fuchsia_free_log_messages(
input: LogMessages<'_>,
)Expand description
Safety
This should only be called with input obtained through
fuchsia_decode_log_messages_to_struct.
#[unsafe(no_mangle)]pub unsafe extern "C" fn fuchsia_free_log_messages(
input: LogMessages<'_>,
)This should only be called with input obtained through
fuchsia_decode_log_messages_to_struct.